<?php 
// Plugin Tool COMPONENT
//
//include the helper file
require_once(dirname(__FILE__).'/../componenthelper.inc.php');

/* respect the name */
$plugintool_component_name = 'plugintool';

/* run the initialization function */
plugintool_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function plugintool_component_init(){
	global $plugintool_component_name;
	
	/* boolean to check for latest version */
	$versionok = plugintool_component_checkversion();
	
	/* Define a description */
	$desc = 'The purpose of the Plugin Tool is to allow you to test Plugins and Commands on your Nagios XI host.<br /> The Plugin Tool is accessed via the Tools menu under "Tools by Box293".<br /><b>NOTE:</b> The Plugin Tool is ONLY accessible by Admins!';
	
	if(!$versionok) {
		$desc = '<b>Error: This component requires Nagios XI 2009R1.2B or later.</b>';
		} /* End if(!$versionok) { */
		
	/* all components require a few arguments to be initialized correctly. */
	$args = array(
		COMPONENT_NAME => $plugintool_component_name,
		COMPONENT_VERSION => '2016-03-25', 
		COMPONENT_DATE => '2016-03-25',
		COMPONENT_AUTHOR => "Troy Lea aka Box293",
		COMPONENT_DESCRIPTION => $desc,
		COMPONENT_TITLE => "Plugin Tool",
		);
	
	/* Register this component with XI */
	register_component($plugintool_component_name,$args);
	
	/* Register the addmenu function */
	if($versionok) {
		register_callback(CALLBACK_MENUS_INITIALIZED,'plugintool_component_addmenu');
		} /* End if($versionok) { */
	} /* End function plugintool_component_init(){ */


///////////////////////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function plugintool_component_checkversion() {

	if(!function_exists('get_product_release')) {
		return false;
		} /* End if(!function_exists('get_product_release')) */
	/* Requires greater than 2009R1.2 */
	if(get_product_release()<114) {
		return false;
		} /* End if(get_product_release()<114) { */
	return true;
	} /* End function plugintool_component_checkversion() { */


function plugintool_component_addmenu($arg=null) {
	/* Only show the menu if the user is an admin */
	if(is_admin() == true) {
		global $plugintool_component_name;
		/* Retrieve the URL for this component */
		$urlbase=get_component_url_base($plugintool_component_name);

		/* Check to see if the "Tools by Box293 menu exists */
		$menu_check = find_menu_item(MENU_TOOLS,"menu-tools-section-toolsbybox293","id");
		
		/* If the "Tools by Box293 menu does NOT exist add it */
		if ($menu_check == false) {
			/* Tools by Box293 menu */ 
			add_menu_item(MENU_TOOLS,array(
				"type" => "menusection",
				"title" => gettext("Tools by Box293"),
				"id" => "menu-tools-section-toolsbybox293",
				"order" => 10000,
				"opts" => array(
					"id" => "toolsbybox293",
					"expanded" => true,
					)
				));
			} /* End if ($menu_check == false) { */
		
		/* Add this to the Tools by Box293 menu */
		add_menu_item(MENU_TOOLS,array(
			"type" => "link",
			"title" => "Plugin Tool",
			"id" => "menu-tools-section-plugin-tool",
			"order" => 10200,
			"opts" => array(
				/* This is the page the menu will actually point to */
				/* all of my actual component workings will happen on this script */
				"href" => $urlbase."/plugin_tool.php",      
				)
			));
		
		/* If the "Tools by Box293 menu does NOT exist End it */
		if ($menu_check == false) {
			add_menu_item(MENU_TOOLS,array(
				"type" => "menusectionend",
				"id" => "menu-tools-sectionend-toolsbybox293",
				"order" => 10999,
				"title" => "",
				"opts" => ""
				));
			} /* End if ($menu_check == false) { */
		} // End if(is_admin() == true) {	
	} /* End function plugintool_component_addmenu($arg=null) { */


?>
